import { Component, OnInit } from '@angular/core';
import { FormArray, FormBuilder, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'app-reactive',
  templateUrl: './reactive.component.html',
  styleUrls: ['./reactive.component.css']
})
export class ReactiveComponent implements OnInit {

  myForm: FormGroup; // FromGroup 是 FromControl 的集合

  constructor(private fb: FormBuilder) { }

  ngOnInit(): void {
    this.myForm = this.fb.group({
      username: ['123', [Validators.required, Validators.minLength(3)]],
      grade: ['5', Validators.required],
      classNo: ['6', Validators.required],
      addr: this.fb.group({
        addr1: 'aaa',
        addr2: 'bbb',
        addr3: 'ccc'
      }),
      interests: this.fb.array(['aaa', 'bbb'])
    });
  }

  get items() {
    return this.myForm.get('interests') as FormArray;
  }

  addItem() {
    this.items.push(this.fb.control(this.items.length));
  }

  delItem() {
    this.items.removeAt(this.items.length - 1);
  }

  removeItem(i: number) {
    this.items.removeAt(i);
  }

}
